@@ -79,7 +79,7 @@ sub _svnroot {
             return $self->{svnroot} = "file://$svnroot/$1";
         }
     }
-    croak "Can't find determine underlying SVN repository for ". $self->repository;
+    confess "Can't find determine underlying SVN repository for ". $self->repository;
 }
 
 # a cmd generating factory
@@ -91,7 +91,7 @@ sub _cmd {
     $args{comment} ||= '';
 
     for ( @{ $REQUIRE_OPTIONS{$type} } ) {
-        croak "$type need option $_" unless $args{$_};
+        confess "$type need option $_" unless $args{$_};
     }
 
     my @cmd;
@@ -209,7 +209,7 @@ sub _cmd {
         @cmd = [ $ENV{'SHIPWRIGHT_SVN'}, 'cat', $self->_svnroot . $args{path} ];
     }
     else {
-        croak "invalid command: $type";
+        confess "invalid command: $type";
     }
 
     return @cmd;
